/*
	DZMSInit.sqf by Vampire
	This is the file that every other file branches off from.
	It checks that it is safe to run, sets relations, and starts mission timers.
*/

private["_modVariant"];

waitUntil{ initialized };

// Lets let the heavier scripts run first
sleep 120;

// Error Check
if ( !isServer ) exitWith { diag_log text format [ "[DZMS]: <ERROR> DZMS is Installed Incorrectly! DZMS is not Running!" ]; };
if ( !isnil( "DZMSInstalled" ) ) exitWith { diag_log text format [ "[DZMS]: <ERROR> DZMS is Installed Twice or Installed Incorrectly!" ]; };

// Global for other scripts to check if DZMS is installed.
DZMSInstalled = true;


diag_log text format [ "[DZMS]: Starting DayZ Mission System." ];


// use east everywhere, since there's never more than 20 or 30 side east groups in DZAI
// no need to set up any relations here

	
// set the new global marker variables

DZMSfMajMarkerSize = 250;
DZMSstrMajMarkerColor = "ColorRed";
DZMSstrMajMarkerBrush = "Grid";
DZMSstrMajMarkerShape = "ELLIPSE";

DZMSfMinMarkerSize = 150;
DZMSstrMinMarkerColor = "ColorRed";
DZMSstrMinMarkerBrush = "Grid";
DZMSstrMinMarkerShape = "ELLIPSE";

DZMSfCookieMarkerSize = 300;
DZMSstrCookieMarkerColor = "ColorBlue";
DZMSstrCookieMarkerBrush = "Grid";
DZMSstrCookieMarkerShape = "ELLIPSE";


// Let's Load the Mission Configuration and other configuration data
call compile preprocessFileLineNumbers "\z\addons\dayz_server\DZMS\DZMSConfig.sqf";
call compile preprocessFileLineNumbers "\z\addons\dayz_server\DZMS\DZMSWeaponCrateList.sqf";
call compile preprocessFileLineNumbers "\z\addons\dayz_server\DZMS\DZMSAIConfig.sqf";


// mission type identifiers
DZMSMissionMinor = 1;
DZMSMissionMajor = 2;
DZMSMissionCookie = 3;


// Report the version
diag_log text format [ "[DZMS]: Currently Running Version: %1" , DZMSVersion ];

// Lets check for a copy-pasted config file
if ( DZMSVersion != "1.1FIN" ) then {
	diag_log text format [ "[DZMS]: Outdated Configuration Detected! Please Update DZMS!" ];
	diag_log text format [ "[DZMS]: Old Versions are not supported by the Mod Author!" ];
};

diag_log text format [ "[DZMS]: Mission and Extended Configuration Loaded!" ];


// Lets get the map name for mission location purposes
DZMSWorldName = toLower format [ "%1" , worldName ];
diag_log text format[ "[DZMS]: %1 Detected. Map Specific Settings Adjusted!" , DZMSWorldName ];


// We need to detect Epoch to change the hive call for vehicle saving
// Epoch doesn't have hive 999 calls and uses 308 publish instead
_modVariant = toLower( getText ( configFile >> "CfgMods" >> "DayZ" >> "dir" ) );
if ( _modVariant == "@dayz_epoch" ) then { DZMSEpoch = true; } else { DZMSEpoch = false; };
if ( ( !( DZMSEpoch ) ) AND ( !( isNil "PVDZE_serverObjectMonitor" ) ) ) then { DZMSEpoch = true; };

if ( DZMSEpoch ) then {
	diag_log text format [ "[DZMS]: DayZ Epoch Detected! Some Scripts Adjusted!" ];
};


// Lets load our functions
call compile preprocessFileLineNumbers "\z\addons\dayz_server\DZMS\DZMSFunctions.sqf";


// these arrays are used to hold units for each mission type
DZMSUnitsMinor = [];
DZMSGroupsMinor = [];

DZMSUnitsHostagesMinor = [];
DZMSGroupsHostagesMinor = [];

DZMSUnitsInVehiclesMinor = [];
DZMSGroupsInVehiclesMinor = [];

DZMSUnitsMajor = [];
DZMSGroupsMajor = [];

DZMSUnitsHostagesMajor = [];
DZMSGroupsHostagesMajor = [];

DZMSUnitsInVehiclesMajor = [];
DZMSGroupsInVehiclesMajor = [];

DZMSUnitsCookie = [];
DZMSGroupsCookie = [];

DZMSUnitsHostagesCookie = [];
DZMSGroupsHostagesCookie = [];

DZMSUnitsInVehiclesCookie = [];
DZMSGroupsInVehiclesCookie = [];


// here's the array of custom markers
DZMSSupportVehicleMarkers = [];
DZMSiHowManySuppVehMarkers = 0;


// here's all the stuff to set up and run the new timeout timers
DZMSMajorTimeoutRUN = true;
DZMSMajorTimeoutEXPIRED = false;

DZMSMinorTimeoutRUN = true;
DZMSMinorTimeoutEXPIRED = false;

DZMSCookieTimeoutRUN = true;
DZMSCookieTimeoutEXPIRED = false;

DZMSMajorAcceptanceTestRunning = true;
DZMSMajorAccepted = false;

DZMSMinorAcceptanceTestRunning = true;
DZMSMinorAccepted = false;

// there is no cookie acceptance test


// set the mission completion flags
DZMSMajDone = false;
DZMSMinDone = false;
DZMSCookieDone = false;


// Let's get the Marker Re-setter running for JIPs to stay updated
[] ExecVM DZMSMarkerLoop;


// now we need to wait the 5 minutes to avoid the server timer bug issue!
diag_log text format [ "[DZMS]: System pause for 6 mins to allow server serverTime bug to run out." ];
sleep 360;
diag_log text format [ "[DZMS]: System pause complete. Starting mission all timers." ];


// Let's get the clocks running finally!
[] ExecVM DZMSMajTimer;
[] ExecVM DZMSMinTimer;
[] ExecVM DZMSCookieTimer;