

// when we come into this script, the mission timeout timer is already running

private [ "_missName" , "_fangle" , "_foffsetx" , "_foffsety" , "_fradius" , "_fradiusR" , "_coordsCtr" , "_coordsObjective" , "_crate" ];

// Name of the Mission
_missName = "Lost Construction Supplies";

// set the mission radius
_fradius = 320;

// DZMSFindPos loops BIS_fnc_findSafePos until it gets a valid result
_coordsCtr = call DZMSFindPos;

[ nil , nil , rTitleText , "A survivor convoy lost a crate of construction supplies.\nRecover it!" , "PLAIN" , 10 ] call RE;

// DZMSAddCookieMarker is a simple script that adds a marker to the location
DZMSfCookieMarkerSize = _fradius;
DZMSstrCookieMarkerColor = "ColorBlue";
DZMSstrCookieMarkerBrush = "Solid";
DZMSstrCookieMarkerShape = "ELLIPSE";
[ _coordsCtr , _missname ] ExecVM DZMSAddCookieMarker;


// now figure out where the box actually is

// find an angle
_fangle = random 360.0;

// find a random radius
_fradiusR = random _fradius;

// find a radial displacement
_foffsetx = _fradiusR * ( cos _fangle );
_foffsety = _fradiusR * ( sin _fangle );

// find the position of the actual box inside the circle defined by the marker
_coordsObjective = [];
_coordsObjective set [ 0 , ( ( _coordsCtr select 0 ) + _foffsetx ) ];
_coordsObjective set [ 1 , ( ( _coordsCtr select 1 ) + _foffsety ) ];
_coordsObjective set [ 2 , 0.0 ];

// a debug string
diag_log text format [ "[DZMS]: Cookie Objective Offsets are %1 , %2" , _foffsetx , _foffsety ];

// Let's add the mission objective box
_crate = createVehicle [ "RUVehicleBox" , _coordsObjective , [] , 0 , "CAN_COLLIDE" ];

// DZMSBoxFill fills the box, DZMSProtectObj prevents it from disappearing
[ _crate , "supply" ] ExecVM DZMSBoxSetup;
[ _crate ] call DZMSProtectObj;


// this concludes mission setup

// Wait until the player is within 5 m
[ _coordsObjective ] call DZMSWaitCookieMissionComp;


// there is no acceptance test, so we need to abort the cookie timeout timer explicityly
DZMSCookieTimeoutRUN = false;


// if the mission was never finished and the timeout has expired, nuke everything and move on
if ( DZMSCookieTimeoutEXPIRED ) then {

    // so now timer and mission complete tests are both shut down....

    // nuke the individual objects and scenery

    _crate call DZMSPurgeObject;

    // nuke the loose backpacks
    [ _coordsObjective ] call DZMSDelBackpacks; 

    // Let everyone know the mission is over
    [ nil , nil , rTitleText , "Lost Construction Supplies mission has timed out." , "PLAIN" , 6 ] call RE;
    diag_log text format [ "[DZMS]: Cookie CM2 Lost Construction Supplies mission has timed out." ];

} else {

    // if the mission timer didn't run out we have a normal mission exit

    // acceptance test has already shut down timer. completion test is shut down too....

    // here is where we would set persistence to any loot vehicles

    // Let everyone know the mission is over
    [ nil , nil , rTitleText , "Survivors have found the lost construction supplies!" , "PLAIN" , 6 ] call RE;
    diag_log text format[ "[DZMS]: Cookie CM2 Lost Construction Supplies mission has ended." ];


    // here is where we test for an ambush!
    _bIsAmbush = random 100;

    if ( _bIsAmbush < 8 ) then {

        // an ambush!
        diag_log text format[ "[DZMS]: Cookie CM2 Lost Construction Supplies ambush extension has begun." ];

        // empty out all the containers
        [ _crate ] call DZMSEmptyBoxCompletely;

        // now make the call to set up the ambush
        [ _coordsObjective , 380 ] call DZMSSetupAmbush; 

        // now post a message
        [ nil , nil , rTitleText , "Survivor spotters have gone silent..." , "PLAIN" , 6 ] call RE;

        // modify the marker
        DZMSstrCookieMarkerColor = "ColorYellow";
        DZMSstrCookieMarkerBrush = "Solid";

        // now wait for the ambush end conditions
        [ _coordsObjective ] call DZMSWaitAmbushEscape;

        // if we get to here, the ambush is over
        [ nil , nil , rTitleText , "All survivors have escaped the bandit ambush." , "PLAIN" , 6 ] call RE;

        // nuke the AI
        call DZMSPurgeAllCookieAI;

        _crate call DZMSPurgeObject;

        // nuke the loose backpacks
        [ _coordsObjective ] call DZMSDelBackpacks; 

        // and the ambush is over
    };
};


// nuke the markers
deleteMarker "DZMSCookieMarker";
deleteMarker "DZMSCookieDot";

//Let the timer know the mission is over
DZMSCookieDone = true;