

// when we come into this script, the mission timeout timer is already running

private [ "_missName" , "_fangle" , "_foffsetx" , "_foffsety" , "_fradius" , "_fradiusR" , "_coordsCtr" , "_coordsObjective" , "_crate1" , "_crate2" , "_crash1" , "_crash2" ];

// Name of the Mission
_missName = "Heavy Weapons Ammo";

// set the mission radius
_fradius = 400;

// DZMSFindPos loops BIS_fnc_findSafePos until it gets a valid result
_coordsCtr = call DZMSFindPos;

[ nil , nil , rTitleText , "Light vehicles carrying heavy weapons resupplies have been taken out.\nBandits are looking for the site. Recover the supplies first." , "PLAIN" , 10 ] call RE;

// DZMSAddCookieMarker is a simple script that adds a marker to the location
DZMSfCookieMarkerSize = _fradius;
DZMSstrCookieMarkerColor = "ColorBlue";
DZMSstrCookieMarkerBrush = "Solid";
DZMSstrCookieMarkerShape = "ELLIPSE";
[ _coordsCtr , _missname ] ExecVM DZMSAddCookieMarker;


// now figure out where the boxes actually are

// find an angle
_fangle = random 400.0;

// find a random radius
_fradiusR = random _fradius;

// find a radial displacement
_foffsetx = _fradiusR * ( cos _fangle );
_foffsety = _fradiusR * ( sin _fangle );

// find the position of the actual box inside the circle defined by the marker
_coordsObjective = [];
_coordsObjective set [ 0 , ( ( _coordsCtr select 0 ) + _foffsetx ) ];
_coordsObjective set [ 1 , ( ( _coordsCtr select 1 ) + _foffsety ) ];
_coordsObjective set [ 2 , 0.0 ];

// a debug string
diag_log text format [ "[DZMS]: Cookie Objective Offsets are %1 , %2" , _foffsetx , _foffsety ];

// Let's add the mission objective boxes
_crate1 = createVehicle [ "TKSpecialWeapons_EP1" , _coordsObjective , [] , 0 , "CAN_COLLIDE" ];
_crate1 setDir random 360;
_crate2 = createVehicle [ "TKSpecialWeapons_EP1" , [ ( _coordsObjective select 0 ) + 2 , ( _coordsObjective select 1 ) + 1 , 0 ] , [] , 0 , "CAN_COLLIDE" ];
_crate2 setDir random 360;

// DZMSBoxFill fills the box, DZMSProtectObj prevents it from disappearing
[ _crate1 , "heavyammo" ] ExecVM DZMSBoxSetup;
[ _crate1 ] call DZMSProtectObj;
[ _crate2 , "heavyammo" ] ExecVM DZMSBoxSetup;
[ _crate2 ] call DZMSProtectObj;


// and some scenery
_crash1 = createVehicle [ "UAZWreck" , [ ( _coordsObjective select 0 ) - 9.3 , ( _coordsObjective select 1 ) - 2.1 , 0 ] , [] , 0 , "CAN_COLLIDE" ];
_crash1 setDir random 360;
[ _crash1 ] call DZMSProtectObj;

_crash2 = createVehicle [ "BRDMWreck" , [ ( _coordsObjective select 0 ) + 7.2 , ( _coordsObjective select 1 ) + 3.3 , 0 ] , [] , 0 , "CAN_COLLIDE" ];
_crash2 setDir random 360;
[ _crash2 ] call DZMSProtectObj;




// this concludes mission setup

// Wait until the player is within 5 m
[ _coordsObjective ] call DZMSWaitCookieMissionComp;


// there is no acceptance test, so we need to abort the cookie timeout timer explicitly
DZMSCookieTimeoutRUN = false;


// if the mission was never finished and the timeout has expired, nuke everything and move on
if ( DZMSCookieTimeoutEXPIRED ) then {

    // so now timer and mission complete tests are both shut down....

    // nuke the individual objects and scenery

    _crate1 call DZMSPurgeObject;
    _crate2 call DZMSPurgeObject;

    _crash1 call DZMSPurgeObject;
    _crash2 call DZMSPurgeObject;

    // nuke the loose backpacks
    [ _coordsObjective ] call DZMSDelBackpacks; 

    // Let everyone know the mission is over
    [ nil , nil , rTitleText , "Heavy Weapons Ammo mission has timed out." , "PLAIN" , 6 ] call RE;
    diag_log text format [ "[DZMS]: Cookie CM6 Heavy Weapons Ammo mission has timed out." ];

} else {

    // if the mission timer didn't run out we have a normal mission exit

    // acceptance test has already shut down timer. completion test is shut down too....

    // here is where we would set persistence to any loot vehicles

    // Let everyone know the mission is over
    [ nil , nil , rTitleText , "Survivors have found the ammunition!" , "PLAIN" , 6 ] call RE;
    diag_log text format[ "[DZMS]: Cookie CM6 Heavy Weapons Ammo mission has ended." ];


    // here is where we test for an ambush!
    _bIsAmbush = random 100;

    if ( _bIsAmbush < 35 ) then {

        // an ambush!
        diag_log text format[ "[DZMS]: Cookie CM6 Heavy Weapons Ammo ambush extension has begun." ];

        // empty out all the containers
        [ _crate1 , _crate2 ] call DZMSEmptyBoxCompletely;

        // now make the call to set up the ambush
        [ _coordsObjective , 200 , 2 , 4 , 3 , 3 , 0 , 3 , DZMSMissionCookie ] call DZMSSetupAmbush; 

        // now post a message
        [ nil , nil , rTitleText , "Survivor spotters have gone silent..." , "PLAIN" , 6 ] call RE;

        // modify the marker
        DZMSstrCookieMarkerColor = "ColorYellow";
        DZMSstrCookieMarkerBrush = "Solid";

        // now wait for the ambush end conditions
        [ _coordsObjective ] call DZMSWaitAmbushEscape;

        // if we get to here, the ambush is over
        [ nil , nil , rTitleText , "All survivors have escaped the bandit ambush." , "PLAIN" , 6 ] call RE;

        // nuke the AI
        call DZMSPurgeAllCookieAI;

        // clean up the AI groups
        call DZMSPurgeCookieGroups;

        _crate1 call DZMSPurgeObject;
        _crate2 call DZMSPurgeObject;

        _crash1 call DZMSPurgeObject;
        _crash2 call DZMSPurgeObject;

        // nuke the loose backpacks
        [ _coordsObjective ] call DZMSDelBackpacks; 

        // and the ambush is over
    };
};


// nuke the markers
deleteMarker "DZMSCookieMarker";
deleteMarker "DZMSCookieDot";

//Let the timer know the mission is over
DZMSCookieDone = true;