/*
	Bandit Stash House by lazyink (Full credit for code to TheSzerdi & TAW_Tonic)
	Updated to new format by Vampire
*/

// when we come into this script, the minor mission timeout timer is already running

private ["_missName","_coords","_base1","_base2","_veh1","_vehicle","_crate1","_crate2"];

//Name of the Mission
_missName = "Weapons Stash House";

//DZMSFindPos loops BIS_fnc_findSafePos until it gets a valid result
_coords = call DZMSFindPos;

[nil,nil,rTitleText,"A bandit black market weapons shipment is held up in a farm house!\nIntercept the shipment before it's moved and take the weapons for yourself!", "PLAIN",10] call RE;

//DZMSAddMinMarker is a simple script that adds a marker to the location
DZMSfMinMarkerSize = 150;
DZMSstrMinMarkerColor = "ColorRed";
DZMSstrMinMarkerBrush = "Grid";
DZMSstrMinMarkerShape = "ELLIPSE";
[_coords,_missName] ExecVM DZMSAddMinMarker;

//We create the scenery
_base1 = createVehicle ["Land_HouseV_1I4",_coords,[], 0, "CAN_COLLIDE"];
_base1 setDir 152.66766;
_base1 setPos _coords;
_base2 = createVehicle ["Land_kulna",[(_coords select 0) + 5.4585, (_coords select 1) - 2.885,0],[], 0, "CAN_COLLIDE"];
_base2 setDir -28.282881;
_base2 setPos [(_coords select 0) + 5.4585, (_coords select 1) - 2.885,0];

//DZMSProtectObj prevents it from disappearing
[_base1] call DZMSProtectObj;
[_base2] call DZMSProtectObj;

//We create the vehicles
_veh1 = ["small"] call DZMSGetVeh;
_vehicle = createVehicle [_veh1,[(_coords select 0) - 10.6206, (_coords select 1) - 0.49,0],[], 0, "CAN_COLLIDE"];

//DZMSSetupVehicle prevents the vehicle from disappearing and sets fuel and such
[ _vehicle , 0 ] call DZMSSetupVehicle;

//We create and fill the crate
_crate1 = createVehicle ["USBasicAmmunitionBox",[(_coords select 0) + 0.7408, (_coords select 1) + 1.565, 0.10033049],[], 0, "CAN_COLLIDE"];
[_crate1,"weapons"] ExecVM DZMSBoxSetup;
[_crate1] call DZMSProtectObj;
_crate2 = createVehicle ["USBasicAmmunitionBox",[(_coords select 0) - 0.2387, (_coords select 1) + 1.043, 0.10033049],[], 0, "CAN_COLLIDE"];
[_crate2,"weapons"] ExecVM DZMSBoxSetup;
[_crate2] call DZMSProtectObj;

//DZMSAISpawn spawns AI to the mission.
//Usage: [_coords, count, skillLevel, unitArray]
[[(_coords select 0) - 4.0796, (_coords select 1) - 11.709,0],6,2, 1 , 0 ] call DZMSAISpawn;
sleep 3;
[[(_coords select 0) + 2.8872, (_coords select 1) + 18.964,0],6,2, 1 , 1 ] call DZMSAISpawn;
sleep 3;


// this concludes mission setup

// start the mission timeout timer running
[] execVM "\z\addons\dayz_server\DZMS\Scripts\DZMSMinorMissionAcceptedTest.sqf";


// Wait until the player is within 30 meters and also meets the kill req
[ _coords ] call DZMSWaitMinorMissionComp;


// if the mission was never accepted and the timeout has expired, nuke everything and move on
if ( DZMSMinorTimeoutEXPIRED ) then {

    // we timed out -- stop the acceptance test
    DZMSMinorAcceptanceTestRunning = false;

    // at this point the acceptance test might be in a WAIT state, and if we rush we could nuke the AI and then see a "death" triggering acceptance....
    sleep 30;

    // so now timer, acceptance, and mission complete tests are all shut down....

    // nuke all the AI
    call DZMSPurgeAllMinorAI;

    // nuke the individual objects and scenery ( if any )

    _base1 call DZMSPurgeObject;
    _base2 call DZMSPurgeObject;

    _vehicle call DZMSPurgeObject;

    _crate1 call DZMSPurgeObject;
    _crate2 call DZMSPurgeObject;

    // nuke the loose backpacks
    [ _coords ] call DZMSDelBackpacks; 

    // Let everyone know the mission is over
    [ nil , nil , rTitleText , "Weapons Stash House mission has timed out." , "PLAIN" , 6 ] call RE;
    diag_log text format [ "[DZMS]: Minor SM3 Weapons Stash House mission has timed out." ];

} else {

    // acceptance test has already shut down timer. completion test is shut down too....

    // here is where we would set persistence to any loot vehicles

    // Call DZMSSaveVeh to attempt to save the vehicles to the database ( if any )
    [ _vehicle ] ExecVM DZMSSaveVeh;

    // clean up the AI groups
    call DZMSPurgeMinorGroups;

    // Let everyone know the mission is over
    [ nil , nil , rTitleText , "Survivors have taken the weapons shipment!" , "PLAIN" , 6 ] call RE;
    diag_log text format[ "[DZMS]: Minor SM3 Weapons Stash House mission has ended."];
};


// nuke the markers
deleteMarker "DZMSMinMarker";
deleteMarker "DZMSMinDot";

//Let the timer know the mission is over
DZMSMinDone = true;