/*
	DZMSAISpawn.sqf by Vampire -- heavy mods since then
	Usage: [position,unitcount,skillLevel,missiongroupusage,groupID,optpos,wprad] execVM "dir\DZMSAISpawn.sqf";
		Position is the coordinates to spawn at [X,Y,Z]
		UnitCount is the number of units to spawn
		SkillLevel is the skill number defined in DZMSAIConfig.sqf
		missiongroupusage is an identifier for which groups we're using --> 1 = Minor, 2 = Major , 3 = Cookie
		groupID is the index of the group being used for this set of spawns ( -1 = next unused group )
		optional position is used to indicate if a group is created over THERE, but moves to HERE and loiters HERE
		optional waypoint radius is used to set waypoint randomizer radii explicitly	
*/

private [ "_position" , "_unitcount" , "_skill" , "_wpRadius" , "_xpos" , "_ypos" , "_unitGroup" , "_aiskin" , "_iloop" , "_optPos" , 
	"_unit" , "_weapon" , "_magazine" , "_missionTypeID" , "_wppos1" , "_wppos2" , "_wppos3" , "_wppos4" , "_iHowManyUnits" , "_strSeq" , 
	"_wp1" , "_wp2" , "_wp3" , "_wp4" , "_wpfin" , "_groupIdx" , "_iHowManyGroups" , "_iLastIndex" , "_bFoundOne" , "_bMove" , "_wpExcursion" ];


// get the passed variables
_position = _this select 0;
_unitcount = _this select 1;
_skill = _this select 2;
_missionTypeID = _this select 3;
_groupIdx = _this select 4;

// figure out if we've specified a different creation position and loiter position
if ( ( count _this ) > 5 ) then {
	_optPos = _this select 5;
	_bMove = true;
} else {
	_bMove = false;
};

// get the waypoint radius from the parameter list, if it was defined
if ( ( count _this ) > 6 ) then {
	_wpRadius = _this select 6;
} else {
	_wpRadius = 20;
};

// initialize the waypoint excursion radius
_wpExcursion = 20;


// check for a fixed target
if ( _skill < 0 ) then {
	_skill = 3;
	_wpRadius = 3;
	_wpExcursion = 0.5;
};

_xpos = _position select 0;
_ypos = _position select 1;


// Create or access the group ... 
// first figure out how many groups are there in the list we're using?

switch ( _missionTypeID ) do {
	case 1: { _iHowManyGroups = count DZMSGroupsMinor; };
	case 2: { _iHowManyGroups = count DZMSGroupsMajor; };
	case 3: { _iHowManyGroups = count DZMSGroupsCookie; };
};


// figure out what the last index of the existing groups is
_iLastIndex = _iHowManyGroups - 1;


// first, check to see if the group ID is nonnegative, which means just use the group indexed or add it to the list...
if ( _groupIdx > -1 ) then {

	// and then see if our target index for the group we're trying to use is larger ....
	if ( _groupIdx > _iLastIndex ) then {

		// we need to add as many groups as we need to get there ...
		for "_iloop" from _iHowManyGroups to _groupIdx do {

			// make a new group
			_unitGroup = createGroup east;

			// put that group into the list
			switch ( _missionTypeID ) do {
				case 1: { DZMSGroupsMinor set [ _iloop , _unitGroup ]; };
				case 2: { DZMSGroupsMajor set [ _iloop , _unitGroup ]; };
				case 3: { DZMSGroupsCookie set [ _iloop, _unitGroup ]; };
			};
		};
	};

	// now that we KNOW we have enough groups in the applicable group list, set the local handle to the one we want to use
	switch ( _missionTypeID ) do {
		case 1: { _unitGroup = DZMSGroupsMinor select _groupIdx; };
		case 2: { _unitGroup = DZMSGroupsMajor select _groupIdx; };
		case 3: { _unitGroup = DZMSGroupsCookie select _groupIdx; };
	};

} else {

	// the group ID is negative, which means we need to search for the first empty group and use that one, OR add one if necessary

	// set a flag
	_bFoundOne = false;

	// find the last index
	_iLastIndex = _iHowManyGroups - 1;

	// traverse the members of the group
	for "_iloop" from 0 to _iLastIndex do {
		
		// how many units are there in this group?
		switch ( _missionTypeID ) do {
			case 1: { _iHowManyUnits = count units ( DZMSGroupsMinor select _iloop ); };
			case 2: { _iHowManyUnits = count units ( DZMSGroupsMajor select _iloop ); };
			case 3: { _iHowManyUnits = count units ( DZMSGroupsCookie select _iloop );};
		};

		// check to see if we found an unused group
		if ( _iHowManyUnits < 1 ) exitWith {

			// an empty or unused group -- so set the flag, set the index, and pick the unit
			_groupIdx = _iloop;
			_bFoundOne = true;

			switch ( _missionTypeID ) do {
				case 1: { _unitGroup = DZMSGroupsMinor select _groupIdx; };
				case 2: { _unitGroup = DZMSGroupsMajor select _groupIdx; };
				case 3: { _unitGroup = DZMSGroupsCookie select _groupIdx; };
			};

			// and then bounce out of the for loop
		};
	};

	// so when we get to here, we need to create a group if we didn't find one we could use...
	if ( !_bFoundOne ) then {

		// make a new group
		_unitGroup = createGroup east;

		// and then we need to shove it into the appropriate list
		switch ( _missionTypeID ) do {
			case 1: { DZMSGroupsMinor set [ _iHowManyGroups , _unitGroup ]; };
			case 2: { DZMSGroupsMajor set [ _iHowManyGroups , _unitGroup ]; };
			case 3: { DZMSGroupsCookie set [ _iHowManyGroups , _unitGroup ]; };
		};

		// and for consistency set the group index to the last one in the list
		_groupIdx = _iHowManyGroups - 1;

		// the local handle is already set to the new group
	};
};


// either we're not re-using the group, or we killed all the units ... so there's no need to purge the group before we use it again....


// Probably unnecessary, but prevents client AI stacking
if ( !isServer ) exitWith {};


// now traverse how many units we want to create
for "_x" from 1 to _unitcount do {

	//  Lets pick a skin from the array
	_aiskin = DZMSBanditSkins call BIS_fnc_selectRandom;
	
	// Lets spawn the unit
	_unit = _unitGroup createUnit [ _aiskin , [ ( _position select 0 ) , ( _position select 1 ) , ( _position select 2 ) ] , [] , 10 , "PRIVATE" ];
	
	// Make him join the correct team
	[ _unit ] joinSilent _unitGroup;
	
	// Add the behaviour
	_unit enableAI "TARGET";
	_unit enableAI "AUTOTARGET";
	_unit enableAI "MOVE";
	_unit enableAI "ANIM";
	_unit enableAI "FSM";
	_unit setCombatMode "YELLOW";
	_unit setBehaviour "COMBAT";
	
	// Remove the items he spawns with by default
	removeAllWeapons _unit;
	removeAllItems _unit;
	
	// Now we need to figure out the loadout, and assign it
	
	// Get the weapon array based on skill
	_weaponArray = [ _skill ] call DZMSGetWeapon;
	
	_weapon = _weaponArray select 0;
	_magazine = _weaponArray select 1;
	
	// diag_log text format [ "[DZMS]: AI Weapon:%1 / AI Magazine:%2" , _weapon , _magazine ];
	
	// Get the gear array
	_aigear = DZMSGearArrays call BIS_fnc_selectRandom;
	_gearmagazines = _aigear select 0;
	_geartools = _aigear select 1;
	
	// Gear the AI backpack
	_aipack = DZMSPacklist call BIS_fnc_selectRandom;

	// Lets add it to the Unit
	for "_i" from 1 to 3 do {

		_unit addMagazine _magazine;
	};

	_unit addWeapon _weapon;
	_unit selectWeapon _weapon;
	
	_unit addBackpack _aipack;
	
	if ( DZMSUseNVG ) then {

		_unit addWeapon "NVGoggles";
	};
	
	{
		_unit addMagazine _x

	} forEach _gearmagazines;
	
	{
		_unit addWeapon _x

	} forEach _geartools;
	
	_aicskill = DZMSSkills1;
	
	// Lets set the skills
	switch (_skill) do {

		case 0: { _aicskill = DZMSSkills0; };
		case 1: { _aicskill = DZMSSkills1; };
		case 2: { _aicskill = DZMSSkills2; };
		case 3: { _aicskill = DZMSSkills3; };
	};
	
	{
		_unit setSkill [ ( _x select 0 ) , ( _x select 1 ) ]

	} forEach _aicskill;
	
	// Lets prepare the unit for cleanup
	_unit addEventHandler [ "Killed" , { [ ( _this select 0 ) , ( _this select 1 ) ] ExecVM DZMSAIKilled; } ];
	_unit setVariable [ "DZMSAI" , true ];
};

// Lets give a launcher if enabled
// The last _unit should still be defined from the FOR above
if ( DZMSUseRPG ) then {

	_unit addWeapon "RPG7V";
	_unit addMagazine "PG7V";
	_unit addMagazine "PG7V";
};


// if the units were created in MOVE mode, then modify the waypoint sequence accordingly
if ( _bMove ) then {
	_xpos = _optPos select 0;
	_ypos = _optPos select 1;
};


// These are 4 waypoints in a NESW pattern around the center
_wppos1 = [ _xpos      , _ypos + _wpExcursion , 0 ];
_wppos2 = [ _xpos + _wpExcursion , _ypos      , 0 ];
_wppos3 = [ _xpos      , _ypos - _wpExcursion , 0 ];
_wppos4 = [ _xpos - _wpExcursion , _ypos      , 0 ];

// We add the 4 waypoints
_wp1 = _unitGroup addWaypoint [ _wppos1 , _wpRadius ];
_wp1 setWaypointType "MOVE";
_wp2 = _unitGroup addWaypoint [ _wppos2 , _wpRadius ];
_wp2 setWaypointType "MOVE";
_wp3 = _unitGroup addWaypoint [ _wppos3 , _wpRadius ];
_wp3 setWaypointType "MOVE";
_wp4 = _unitGroup addWaypoint [ _wppos4 , _wpRadius ];
_wp4 setWaypointType "MOVE";

// Then we add a center waypoint that tells them to visit the rest
_wpfin = _unitGroup addWaypoint [ [ _xpos , _ypos , 0 ] , _wpRadius ];
_wpfin setWaypointType "CYCLE";


// finally, add the units we created to the list of all units for this category
switch ( _missionTypeID ) do {
	case 1: { DZMSUnitsMinor = DZMSUnitsMinor + ( units _unitGroup ); };
	case 2: { DZMSUnitsMajor = DZMSUnitsMajor + ( units _unitGroup ); };
	case 3: { DZMSUnitsCookie = DZMSUnitsCookie + ( units _unitGroup ); };
};


switch ( _missionTypeID ) do {
	case 1: { _strSeq = "DZMSUnitsMinor"; };
	case 2: { _strSeq = "DZMSUnitsMajor"; };
	case 3: { _strSeq = "DZMSUnitsCookie"; };
};

diag_log text format[ "[DZMS]: %3 %1 AI Spawned of %2 units requested for group %4" , count (units _unitGroup) , _unitcount , _strSeq , _groupIdx  ];
