if ( isServer ) then {

	// main block spawns an instance of the main block of the routine. seems gratuitous!
	_this spawn {

//		private[ "_vehicle" , "_position" , "_unitgroup" , "_num_waypoints" , "_leader" , "_count_wp" , "_waypoints" , "_waypoint_prev" , "_msg" , "_wp"];
		private[ "_vehicle" , "_position" , "_unitgroup" , "_num_waypoints" , "_leader" , "_count_wp" , "_waypoint_prev" , "_msg" , "_wp"];

		// pulls in the parameter block
		_vehicle 		= _this select 0;
		_position 		= _this select 1;
		_unitgroup 	= _this select 2;
		_num_waypoints 	= _this select 3;
		_leader		= leader _unitgroup;
		_count_wp		= count wai_patrol_locations;
		_waypoint_prev	= "";

		// unlocks the vehicle
		_vehicle setvehiclelock "UNLOCKED";

		// set combat mode
		_unitgroup setBehaviour "COMBAT";
		_unitgroup setCombatMode "YELLOW";


		// this section assigns the driver and gunners and puts remaining AI in the cargo rider positions
		{

			if( _leader == _x ) then {
				_x assignAsDriver _vehicle;
				_x moveInDriver _vehicle;
				diag_log format[ "[WAI] %1 assigned as driver" , _x ];
			} else {

				if ( ( _vehicle emptyPositions "GUNNER" ) > 0 ) then {
					_x assignAsGunner _vehicle;
					_x moveInGunner _vehicle;
					diag_log format[ "[WAI] %1 assigned as gunner" , _x ];
				} else {
					_x moveInCargo _vehicle;
					diag_log format[ "[WAI] %1 assigned as cargo" , _x ];
				};

			};

		} forEach units _unitgroup;	// end of driver and gunner assignment block


		// wait until the driver gets into the vehicle
		waitUntil {(_vehicle emptyPositions "DRIVER" == 0)};

		diag_log format["[WAI] Driver is inside vehicle, continue.."];


		// this spawns a block of code that refuels the vehicle and checks for vehicle operational status and driver life
		// this block of code terminates when the vehicle is dead or when the driver is
		[ _vehicle , _unitgroup ] spawn {

			private[ "_vehicle" , "_unitgroup" , "_runmonitor" ];

			_vehicle 	= _this select 0;
			_unitgroup = _this select 1;
			_runmonitor = true;

			// this block refuels the vehicle as long as the driver is alive and the vehicle can move
			while { ( canMove _vehicle && _runmonitor ) } do {
				if ( fuel _vehicle < 0.2 ) then { _vehicle setfuel 1; };
				if ( !( alive leader _unitgroup ) ) then {
					diag_log "[WAI] Driver was killed. Ejecting AI and removing waypoints.";
					_runmonitor = false;
				};
				sleep .5;
			};

			// the driver is dead or the vehicle is dead
			if ( _runmonitor ) then {
				diag_log "[WAI] Vehicle became undriveable, ejecting crew.";
			};

			// kill all the waypoints
//			deleteWaypoint [ _unitgroup , all ];
			while { ( count ( waypoints _unitgroup ) ) > 0 } do
			{
//				deleteWaypoint ( ( waypoints _unitgroup ) select 0 );
				deleteWaypoint [ _unitgroup , 0 ];
			};


			// wait until the vehicle stops
			waitUntil { ( speed _vehicle < 10 ) };

			// eject all AI in the vehicle
			{
				_x action [ "eject" , vehicle _x ];
			} forEach crew _vehicle;

			// set the waypoint to wherever they stopped, set them to guard mode, and make them ornery
			_wp = _unitgroup addWaypoint [ ( getPos _vehicle ) , 0 ];
			_wp setWaypointType "GUARD";
			_wp setWaypointBehaviour "COMBAT";

		}; // end of spawn block that monitors fuel, vehicle status, and driver life


		// this loop iterates through the number of waypoints specified
		for "_i" from 1 to _num_waypoints do {

			// pick a new waypoint!
			_rand_nr = ceil( random( ( _count_wp - 1 ) ) );
			_waypoint = ( wai_patrol_locations select _rand_nr );
// i don't think we need the variable _waypoints (plural). It's not used anywhere except right here....
//			_waypoints set[ _rand_nr , -1 ];
//			_waypoints = _waypoints - [ -1 ];
			
			_wp = _unitgroup addWaypoint [ ( _waypoint select 1 ) , 0 ];
			
			// if we're on the last waypoint, then stop moving around
			if ( _i == _num_waypoints ) then { 
				_wp setWaypointType "GUARD";
			} else { 
				_wp setWaypointType "MOVE";
			};

			// set combat behavior
			_wp setWaypointBehaviour "CARELESS";
			_wp setWaypointCombatMode "YELLOW";


			// this block prints out the interim waypoint messages
			if ( _waypoint_prev != "" ) then {
				// there is a previous waypoint --d escribe where we're going next
				_msg = format[ "[RADIO] The patrol arrived at %1, heading towards %2" , _waypoint_prev , ( _waypoint select 0 ) ];
			} else {
				// there is no previous waypoint -- this is the first time through the loop
				_msg = format[ "[RADIO] The patrol is seen moving towards %1" , ( _waypoint select 0 ) ];
			};
			
			// wait a short random time
			sleep random( 10 );
			
			if ( wai_radio_announce ) then {
				RemoteMessage = [ "radio" , _msg ];
				publicVariable "RemoteMessage";
			} else {
				[ nil , nil , rTitleText , _msg , "PLAIN" , 10 ] call RE;
			};
			
			// enter a wait loop -- until EITHER we reach a waypoint, OR the leader is dead, OR the vehicle can't move
			waitUntil{ sleep 1; ( ( _vehicle distance ( _waypoint select 1 ) < 30 ) || !( alive leader _unitgroup ) || ( !canMove _vehicle ) ) };


			// at this point, if we're still moving, we should update the marker location for the last waypoint hit
			// if we got here, and it's not the last waypoint, then _i will be less than _num_waypoints
			// if this is the end, at _i == _num_waypoints, there's no need to update the marker because the marker will vanish shortly
			if ( _i < _num_waypoints ) then {
//////		this is where the marker update code goes
			};			


			// if the leader is dead or the vehicle broken, we're done with waypoints
			if ( !( alive leader _unitgroup ) || ( !canMove _vehicle ) ) exitWith {
				diag_log "[WAI] Crew has been ejected, stopping creation of new waypoints.";
			};

			// set the last waypoint to the current waypoint
			_waypoint_prev = ( _waypoint select 0 );

		}; // end of each waypoint loop

	}; // end of _this spawn loop

}; // end if isServer loop